Getting started
===============

Requirements
------------

pydae requires a number of Python packages, notably:

* NumPy, for basic numerical routines
* matplotlib, for static orbit plotting
* numba (when using CPython), for accelerating the code
* SciPy, for root finding and numerical propagation
* Sympy, library for symbolic mathematics

pydae is usually tested on Linux and Windows on Python
3.6, 3.7 and 3.8 against latest NumPy.
It should work on OS X without problems.

Installation
------------

The easiest and fastest way to get the package up and running is to
install pydae using pip:

  $ pip install pydae 


